Alignment

Struct Alignment 

pub struct Alignment { /* private fields */ }
Sequence alignment result.

Implementations

Source

impl Alignment

pub fn get_score(&self) -> i32

Get alignment score.

pub fn get_end_query(&self) -> i32

Get end position of query sequence.

pub fn get_end_ref(&self) -> i32

Get end position of the reference sequence.

pub fn get_matches(&self) -> Result<i32>

Get number of matches in the alignment.

pub fn get_similar(&self) -> i32

pub fn get_length(&self) -> Result<i32>

Get alignment length.

pub fn get_score_table(&self) -> Result<Table<'_>>

Get the score table.

The table has dimensions (query_len, ref_len) and contains alignment scores for all positions in the dynamic programming table.

Example
let result = aligner.align(Some(query), reference)?;
let table = result.get_score_table()?;

// Access specific cell
if let Some(score) = table.get(0, 0) {
    println!("Score at (0, 0): {}", score);
}

// Get final score
println!("Final score: {}", table.last());
pub fn get_matches_table(&self) -> Result<Table<'_>>

Get the matches table.

pub fn get_similar_table(&self) -> Result<Table<'_>>

Get the similar table.

pub fn get_length_table(&self) -> Result<Table<'_>>

Get the length table.

pub fn get_score_row(&self) -> Result<&[i32]>

Get score row.

pub fn get_matches_row(&self) -> Result<&[i32]>

Get matches row.

pub fn get_similar_row(&self) -> Result<&[i32]>

Get similar row.

pub fn get_length_row(&self) -> Result<&[i32]>

Get length row.

pub fn get_score_col(&self) -> Result<&[i32]>

Get score column.

pub fn get_matches_col(&self) -> Result<&[i32]>

Get matches column.

pub fn get_similar_col(&self) -> Result<&[i32]>

Get similar column.

pub fn get_length_col(&self) -> Result<&[i32]>

Get length column

pub fn get_trace_table(&self) -> Result<TracebackTable<'_>>

Get the trace table.

pub fn print_traceback(&self, query: &[u8], reference: &[u8])

Get alignment strings and statistics

pub fn get_traceback_strings( &self, query: &[u8], reference: &[u8], ) -> Result<Traceback>

Get alignment strings.

pub fn get_cigar(&self, query: &[u8], reference: &[u8]) -> Result<String>

Get CIGAR string.

pub fn is_global(&self) -> bool

Check if the alignment mode is global.

pub fn is_semi_global(&self) -> bool

Check if the alignment mode is semi-global.

pub fn is_local(&self) -> bool

Check if the alignment mode is local.

pub fn is_saturated(&self) -> bool

Check if the solution width is saturated (i.e., using 8-bit solution width first and falling back to 16-bit if necessary).

pub fn is_banded(&self) -> bool

Check if banded alignment is used.

pub fn is_scan(&self) -> bool

Check if vector strategy is scan.

pub fn is_striped(&self) -> bool

Check if vector strategy is striped.

pub fn is_diag(&self) -> bool

Check if vector strategy is diagonal.

pub fn is_blocked(&self) -> bool

pub fn is_stats(&self) -> bool

Check if statistics are returned from alignment.

pub fn is_stats_table(&self) -> bool

Check if result is a stats table

pub fn is_table(&self) -> bool

Check if result is a table

pub fn is_rowcol(&self) -> bool

Check if result is a last row and column of table

pub fn is_stats_rowcol(&self) -> bool

Check if result is a row and column of table with additional statistics.

pub fn is_trace(&self) -> bool

Check if result is trace enabled.