pub struct Alignment { /* private fields */ }Expand description
Sequence alignment result.
Implementations
Sourceimpl Alignment
impl Alignment
Sourcepub fn get_end_query(&self) -> i32
pub fn get_end_query(&self) -> i32
Get end position of query sequence.
Sourcepub fn get_end_ref(&self) -> i32
pub fn get_end_ref(&self) -> i32
Get end position of the reference sequence.
Sourcepub fn get_matches(&self) -> Result<i32>
pub fn get_matches(&self) -> Result<i32>
Get number of matches in the alignment.
pub fn get_similar(&self) -> i32
Sourcepub fn get_length(&self) -> Result<i32>
pub fn get_length(&self) -> Result<i32>
Get alignment length.
Sourcepub fn get_score_table(&self) -> Result<Table<'_>>
pub fn get_score_table(&self) -> Result<Table<'_>>
Get the score table.
The table has dimensions (query_len, ref_len) and contains alignment scores for all positions in the dynamic programming table.
Example
let result = aligner.align(Some(query), reference)?;
let table = result.get_score_table()?;
// Access specific cell
if let Some(score) = table.get(0, 0) {
println!("Score at (0, 0): {}", score);
}
// Get final score
println!("Final score: {}", table.last());Sourcepub fn get_matches_table(&self) -> Result<Table<'_>>
pub fn get_matches_table(&self) -> Result<Table<'_>>
Get the matches table.
Sourcepub fn get_similar_table(&self) -> Result<Table<'_>>
pub fn get_similar_table(&self) -> Result<Table<'_>>
Get the similar table.
Sourcepub fn get_length_table(&self) -> Result<Table<'_>>
pub fn get_length_table(&self) -> Result<Table<'_>>
Get the length table.
Sourcepub fn get_score_row(&self) -> Result<&[i32]>
pub fn get_score_row(&self) -> Result<&[i32]>
Get score row.
Sourcepub fn get_matches_row(&self) -> Result<&[i32]>
pub fn get_matches_row(&self) -> Result<&[i32]>
Get matches row.
Sourcepub fn get_similar_row(&self) -> Result<&[i32]>
pub fn get_similar_row(&self) -> Result<&[i32]>
Get similar row.
Sourcepub fn get_length_row(&self) -> Result<&[i32]>
pub fn get_length_row(&self) -> Result<&[i32]>
Get length row.
Sourcepub fn get_score_col(&self) -> Result<&[i32]>
pub fn get_score_col(&self) -> Result<&[i32]>
Get score column.
Sourcepub fn get_matches_col(&self) -> Result<&[i32]>
pub fn get_matches_col(&self) -> Result<&[i32]>
Get matches column.
Sourcepub fn get_similar_col(&self) -> Result<&[i32]>
pub fn get_similar_col(&self) -> Result<&[i32]>
Get similar column.
Sourcepub fn get_length_col(&self) -> Result<&[i32]>
pub fn get_length_col(&self) -> Result<&[i32]>
Get length column
Sourcepub fn get_trace_table(&self) -> Result<TracebackTable<'_>>
pub fn get_trace_table(&self) -> Result<TracebackTable<'_>>
Get the trace table.
Sourcepub fn print_traceback(&self, query: &[u8], reference: &[u8])
pub fn print_traceback(&self, query: &[u8], reference: &[u8])
Get alignment strings and statistics
Sourcepub fn get_traceback_strings(
&self,
query: &[u8],
reference: &[u8],
) -> Result<Traceback>
pub fn get_traceback_strings( &self, query: &[u8], reference: &[u8], ) -> Result<Traceback>
Get alignment strings.
Sourcepub fn is_semi_global(&self) -> bool
pub fn is_semi_global(&self) -> bool
Check if the alignment mode is semi-global.
Sourcepub fn is_saturated(&self) -> bool
pub fn is_saturated(&self) -> bool
Check if the solution width is saturated (i.e., using 8-bit solution width first and falling back to 16-bit if necessary).
Sourcepub fn is_striped(&self) -> bool
pub fn is_striped(&self) -> bool
Check if vector strategy is striped.
pub fn is_blocked(&self) -> bool
Sourcepub fn is_stats_table(&self) -> bool
pub fn is_stats_table(&self) -> bool
Check if result is a stats table
Sourcepub fn is_stats_rowcol(&self) -> bool
pub fn is_stats_rowcol(&self) -> bool
Check if result is a row and column of table with additional statistics.